@@ -72,6 +72,7 @@ from bloom.commands.git.patch.common import set_patch_config
 
 from bloom.packages import get_package_data
 
+from bloom.util import to_unicode
 from bloom.util import execute_command
 from bloom.util import get_rfc_2822_date
 from bloom.util import maybe_continue
@@ -124,6 +125,8 @@ def __place_template_folder(group, src, dst, gbp=False):
                 debug("Removing existing file '{0}'".format(template_dst))
                 os.remove(template_dst)
             with open(template_dst, 'w') as f:
+                if not isinstance(template, str):
+                    template = template.decode('utf-8')
                 f.write(template)
             shutil.copystat(template_abs_path, template_dst)
 
@@ -205,7 +208,7 @@ def get_changelogs(package, releaser_history=None):
             changes_str = []
             date_str = get_rfc_2822_date(date)
             for item in changes:
-                changes_str.extend(['  ' + i for i in str(item).splitlines()])
+                changes_str.extend(['  ' + i for i in to_unicode(item).splitlines()])
             # Each entry has (version, date, changes, releaser, releaser_email)
             releaser, email = releaser_history.get(version, maintainer)
             changelogs.append((
@@ -372,7 +375,7 @@ def get_package_from_branch(branch):
             "the release generator first to split packages into "
             "individual branches.")
     if type(packages) is dict:
-        return packages.values()[0]
+        return list(packages.values())[0]
 
 
 def debianize_string(value):
